Cmp

Struct Cmp 

pub struct Cmp { /* private fields */ }
The comparison wake_op applies to the old value of the second futex.

A Cmp must be combined with an Op by using the plus operator. For example: Op::assign(1) + Cmp::eq(0)

The argument to any comparison must be below 1 << 12 (= 4096).

Implementations

Source

impl Cmp

pub fn eq(value: u32) -> Self

Check if the old value of the futex equals this value.

pub fn ne(value: u32) -> Self

Check if the old value of the futex does not equal this value.

pub fn lt(value: u32) -> Self

Check if the old value of the futex is less than this value.

pub fn le(value: u32) -> Self

Check if the old value of the futex is less than or equal to this value.

pub fn gt(value: u32) -> Self

Check if the old value of the futex is greater than this value.

pub fn ge(value: u32) -> Self

Check if the old value of the futex is greater than or equal to this value.